==> haskell-hpack-0.17.0-18-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hpack.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hpack
version: 0.17.0
id: hpack-0.17.0-ENdpNgDvDtl7zqVQ7CNule
key: hpack-0.17.0-ENdpNgDvDtl7zqVQ7CNule
license: MIT
maintainer: Simon Hengel <sol@typeful.net>
homepage: https://github.com/sol/hpack#readme
synopsis: An alternative format for Haskell packages
description:
    See README at <https://github.com/sol/hpack#readme>
category: Development
exposed: True
exposed-modules:
    Hpack Hpack.Config Hpack.Run Hpack.Yaml
hidden-modules: Hpack.FormattingHints Hpack.GenericsUtil
                Hpack.Haskell Hpack.Render Hpack.Util Paths_hpack
abi: 0f833a162cf2378ae43b37f3178f54b7
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/hpack-0.17.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/hpack-0.17.0
data-dir: /usr/share/arm-linux-ghc-8.0.1/hpack-0.17.0
hs-libraries: HShpack-0.17.0-ENdpNgDvDtl7zqVQ7CNule
depends:
    Glob-0.7.14-JPiVrtb5jL5BeQhtkal5dv
    aeson-1.1.2.0-1uNomby1VUYFNhcECz5Xvt base-4.9.0.0
    base-compat-0.9.3-DrSgCcixJxxKb6RsGgHyiF bytestring-0.10.8.1
    containers-0.5.7.1 deepseq-1.4.2.0 directory-1.2.6.2
    filepath-1.4.1.0 text-1.2.2.2-9rr3K4o0GAG9P33dGDnV9v
    unordered-containers-0.2.8.0-Njz6QHP7Gk5G9PhT6D28J
    yaml-0.8.23-2g4ghz9iEN3Bv19gf809hJ
haddock-interfaces: /usr/share/doc/haskell-hpack/html/hpack.haddock
haddock-html: /usr/share/doc/haskell-hpack/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-hpack-0.17.0-19-armv7h.pkg.tar.xz: usr/share/haskell/register/haskell-hpack.sh <==
#!/bin/sh
export PATH='/usr/lib/distcc/bin:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: hpack
version: 0.17.0
id: hpack-0.17.0-2ERBLz5VZIYIndzmSGkIjJ
key: hpack-0.17.0-2ERBLz5VZIYIndzmSGkIjJ
license: MIT
maintainer: Simon Hengel <sol@typeful.net>
homepage: https://github.com/sol/hpack#readme
synopsis: An alternative format for Haskell packages
description:
    See README at <https://github.com/sol/hpack#readme>
category: Development
exposed: True
exposed-modules:
    Hpack Hpack.Config Hpack.Run Hpack.Yaml
hidden-modules: Hpack.FormattingHints Hpack.GenericsUtil
                Hpack.Haskell Hpack.Render Hpack.Util Paths_hpack
abi: e94de59d61db28dfab0dbba715b3ba8b
trusted: False
import-dirs: /usr/lib/ghc-8.0.1/site-local/hpack-0.17.0
library-dirs: /usr/lib/ghc-8.0.1/site-local/hpack-0.17.0
data-dir: /usr/share/arm-linux-ghc-8.0.1/hpack-0.17.0
hs-libraries: HShpack-0.17.0-2ERBLz5VZIYIndzmSGkIjJ
depends:
    Glob-0.7.14-JPiVrtb5jL5BeQhtkal5dv
    aeson-1.1.2.0-6MVvUcgiXyL5LInpwFqRIH base-4.9.0.0
    base-compat-0.9.3-DrSgCcixJxxKb6RsGgHyiF bytestring-0.10.8.1
    containers-0.5.7.1 deepseq-1.4.2.0 directory-1.2.6.2
    filepath-1.4.1.0 text-1.2.2.2-9rr3K4o0GAG9P33dGDnV9v
    unordered-containers-0.2.8.0-Njz6QHP7Gk5G9PhT6D28J
    yaml-0.8.23-GVM4r8hhN8WEBBJV7tAgAb
haddock-interfaces: /usr/share/doc/haskell-hpack/html/hpack.haddock
haddock-html: /usr/share/doc/haskell-hpack/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
